@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 """Collection of singlet EKOs."""
 
 import numba as nb
 import numpy as np
 
-from .. import anomalous_dimensions as ad
+from ekore import anomalous_dimensions as ad
 from .. import beta
 from . import as4_evolution_integrals as as4_ei
 from . import evolution_integrals as ei
