@@ -1,16 +1,17 @@
-# -*- coding: utf-8 -*-
 """Tools to evolve actual PDFs."""
 import pathlib
 
 import numpy as np
 
 import eko
-import eko.output.legacy
 from eko import basis_rotation as br
+from eko.io import EKO
 from ekomark import apply
 
 from . import genpdf, info_file
 
+DEFAULT_NAME = "eko.tar"
+
 
 def evolve_pdfs(
     initial_PDF_list,
@@ -46,29 +47,30 @@ def evolve_pdfs(
     info_update : dict
         dict of info to add or update to default info file
     """
-    eko_output = None
+    # update op and th cards
     if path is not None:
-        my_path = pathlib.Path(path)
-        if my_path.is_dir():
-            outpath = my_path / ekofileid(theory_card, operators_card)
-            eko_output = eko.output.legacy.load_tar(outpath)
-        else:
-            eko_output = eko.output.legacy.load_tar(my_path)
+        eko_path = pathlib.Path(path)
+        if eko_path.is_dir():
+            eko_path = eko_path / DEFAULT_NAME
     else:
-        eko_output = eko.run_dglap(theory_card, operators_card)
-        if store_path is not None:
-            eko.output.legacy.dump_tar(eko_output, store_path)
+        if store_path is None:
+            raise ValueError("'store_path' required if 'path' is not provided.")
+        eko.solve(theory_card, operators_card, path=store_path)
+        eko_path = store_path
 
     evolved_PDF_list = []
-    for initial_PDF in initial_PDF_list:
-        evolved_PDF_list.append(apply.apply_pdf(eko_output, initial_PDF, targetgrid))
+    with EKO.read(eko_path) as eko_output:
+        for initial_PDF in initial_PDF_list:
+            evolved_PDF_list.append(
+                apply.apply_pdf(eko_output, initial_PDF, targetgrid)
+            )
 
     if targetgrid is None:
-        targetgrid = operators_card["interpolation_xgrid"]
+        targetgrid = operators_card.rotations.xgrid
     if info_update is None:
         info_update = {}
-    info_update["XMin"] = targetgrid[0]
-    info_update["XMax"] = targetgrid[-1]
+    info_update["XMin"] = targetgrid.raw[0]
+    info_update["XMax"] = targetgrid.raw[-1]
     info = info_file.build(
         theory_card,
         operators_card,
@@ -76,13 +78,14 @@ def evolve_pdfs(
         info_update=info_update,
     )
     all_member_blocks = []
+    targetlist = targetgrid.raw.tolist()
     for evolved_PDF in evolved_PDF_list:
         all_blocks = []
         block = genpdf.generate_block(
-            lambda pid, x, Q2, evolved_PDF=evolved_PDF: targetgrid[targetgrid.index(x)]
-            * evolved_PDF[Q2]["pdfs"][pid][targetgrid.index(x)],
-            xgrid=targetgrid,
-            Q2grid=operators_card["Q2grid"],
+            lambda pid, x, Q2, evolved_PDF=evolved_PDF: targetlist[targetlist.index(x)]
+            * evolved_PDF[Q2]["pdfs"][pid][targetlist.index(x)],
+            xgrid=targetlist,
+            Q2grid=operators_card.mu2grid,
             pids=np.array(br.flavor_basis_pids),
         )
         # all_blocks will be useful in case there will be necessity to dump many blocks
@@ -94,22 +97,3 @@ def evolve_pdfs(
 
     if install:
         genpdf.install_pdf(name)
-
-
-def ekofileid(theory_card, operators_card):
-    """
-    Return a common filename composed by the hashes.
-
-    Parameters
-    ----------
-    theory_card : dict
-        theory card
-    operators_card : dict
-        operators card
-
-    Returns
-    -------
-    str
-        file name
-    """
-    return f"o{operators_card['hash'][:6]}_t{theory_card['hash'][:6]}.tar"
