@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Database tables
 """
@@ -23,3 +22,5 @@ class Operator(Base):  # pylint: disable=too-few-public-methods
     ev_op_iterations = Column(Integer)
     Q2grid = Column(Text)
     backward_inversion = Column(Text)
+    polarized = Column(Boolean)
+    time_like = Column(Boolean)
